@@ -1,5 +1,4 @@
 import datetime
-
 import requests
 import json
 from jsonpath import jsonpath
@@ -8,9 +7,14 @@ import random
 import hmac
 from hashlib import sha1
 import random
+# from Platform import Platform
+import itertools
+
 
 
 platform = "FACEBOOK"
+count = 0
+num = 100
 def create_general_post(data):
     """创建普通贴文销售，返回响应和贴文销售ID
     sc_common_interface
@@ -56,7 +60,7 @@ def create_general_post(data):
             time.sleep(1)
         finally:
             count += 1
-        if count > 20:
+        if count > num:
             break
     response = response.json()
     print("创建贴文返回",response)
@@ -108,7 +112,7 @@ def create_commerce_post(data):
             time.sleep(1)
         finally:
             count +=1
-        if count>20:
+        if count>num:
             break
     response = response.json()
     # print(response)
@@ -156,8 +160,13 @@ def search_oa_gift(data):
         response = requests.get(url, headers=headers, params=params).json()
         items = response["data"]["items"]
 
-    # 返回第一个赠品
+    # 返回赠品数量不是0
+    # print(json.dumps(items))
+    quantityList = jsonpath(items,"$..quantity")
     gift_info = items[0]
+    for a,b in enumerate(quantityList):
+        if b!=0:
+            gift_info = items[a]
     # 下划线命名转变为驼峰命名
     change_dict_into_hump(gift_info)
 
@@ -173,6 +182,9 @@ def search_oa_product(data):
     env = data["env"]
     headers = data["headers"]
     url = "%s/openApi/proxy/v1/products?page=1&per_page=4" %env
+    if "query" in data:
+        query = data["query"]
+        url = "%s/openApi/proxy/v1/products?page=1&per_page=4&query=%s" % (env,query)
     response = requests.get(url, headers=headers).json()
     return response
 
@@ -345,9 +357,16 @@ def get_page_post(data):
     fb group:GROUP_POST
     :return:响应
     """
+    #时间戳转换
     env = data["env"]
     headers = data["headers"]
     platform = "FACEBOOK"
+    type = "POST"
+    days = 180
+    current_time = datetime.datetime.now()
+    since = int((current_time - datetime.timedelta(days=days)).timestamp())
+    if "type" in data:
+        type = data["type"]
     if "platform" in data:
         platform = data["platform"].upper()
     if "page_id" in data:
@@ -356,20 +375,27 @@ def get_page_post(data):
         page_id, page_name, group_id = get_channel_info(data)
         if platform=="FB_GROUP":
             page_id = group_id
-    type = "POST"
-    if "type" in data:
-        type = data["type"]
-    since = 1699027200
-    if "since" in data:
-        since = data["since"]
+            type = "GROUP_POST"
+            since = int((current_time - datetime.timedelta(days=7)).timestamp())
+    if "days" in data:
+        days = data["days"]
+        since = int((current_time - datetime.timedelta(days=int(days))).timestamp())
+
+    # since = 1699027200
+    # if "since" in data:
+    #     since = data["since"]
     page_size = 50
     if "page_size" in data:
         page_size = data
     params = {"page_size":page_size,"type":type,"since":since,"party_channel_id":page_id,"platform":platform}
     url = "%s/api/posts/post"%env
+    print("params",params)
     response =requests.get(url,headers=headers,params=params).json()
     return response
 
+
+
+
 def relate_post(data):
     """
     链接贴文，只链接返回的第一个可链接的贴文
@@ -382,28 +408,40 @@ def relate_post(data):
     sales_id = data["sales_id"]
     if "platform" in data:
         platform = data["platform"].upper()
-    response = get_page_post(data)
-    available_post_list = []
-    related_sales = jsonpath(response,"$..related_sales")
-    print("查询到的贴文信息",related_sales)
-    for index,value in enumerate(related_sales):
-        if value==False:
-            available_post_list.append(response["data"]["data"][index])
     url = "%s/api/posts/post/sales/%s/addPost"%(env,sales_id)
+    body = {}
+    if platform=="FB_GROUP":
+        page_id = data["page_id"]
+        relationUrl = data["relationUrl"]
+        body = {
+            "pageId": page_id,
+            "platform": "FB_GROUP",
+            "relationUrl": relationUrl
+            }
+    else:
+        response = get_page_post(data)
+        available_post_list = []
+        related_sales = jsonpath(response,"$..related_sales")
+        print("查询到的贴文信息",related_sales)
+        for index,value in enumerate(related_sales):
+            if value==False:
+                available_post_list.append(response["data"]["data"][index])
+
     # platform = "FACEBOOK"
     # print(available_post_list[0])
-    page_id = jsonpath(available_post_list[0],"$..from.id")[0]
-    page_name = jsonpath(available_post_list[0],"$..from.name")[0]
-    post_id = jsonpath(available_post_list[0],"$.id")[0]
-    message = jsonpath(available_post_list[0],"$.message")[0]
-    permalink_url = jsonpath(available_post_list[0],"$.permalink_url")[0]
-    status_type = jsonpath(available_post_list[0],"$.status_type")[0]
-    picture = jsonpath(available_post_list[0],"$.picture")[0]
-    body = {"pageId": page_id, "pageName": page_name, "platform": platform,
-        "postList": [{"postId": post_id, "postTitle": page_name,
-                      "postDescription": message, "postImageUrl": picture,
-                      "permalinkUrl": permalink_url,
-                      "statusType": status_type}]}
+        page_id = jsonpath(available_post_list[0],"$..from.id")[0]
+        page_name = jsonpath(available_post_list[0],"$..from.name")[0]
+        post_id = jsonpath(available_post_list[0],"$.id")[0]
+        message = jsonpath(available_post_list[0],"$.message")[0]
+        permalink_url = jsonpath(available_post_list[0],"$.permalink_url")[0]
+        status_type = jsonpath(available_post_list[0],"$.status_type")[0]
+        picture = jsonpath(available_post_list[0],"$.picture")[0]
+        body = {"pageId": page_id, "pageName": page_name, "platform": platform,
+            "postList": [{"postId": post_id, "postTitle": page_name,
+                          "postDescription": message, "postImageUrl": picture,
+                          "permalinkUrl": permalink_url,
+                          "statusType": status_type}]}
+
     response = requests.post(url,headers=headers,json=body).json()
     return response
 
@@ -431,6 +469,7 @@ def create_fb_text_post(data):
     body = {"postDescription":postDescription,"platform":platform,
             "url":[],"mediaFbid":[],"pageId":page_id}
     response = requests.post(url,headers=headers,json=body).json()
+    print("创建贴文返回",response)
     post_id = response["data"]["post_id"]
     post_pid = response["data"]["id"]
     return post_id,post_pid,response
@@ -445,15 +484,64 @@ def search_post_product(data):
     headers = data["headers"]
     url = "%s/api/posts/common/product/key/spu/list?page=1&searchType=ALL&pageSize=10"%env
     response = requests.get(url, headers=headers).json()
-    productSpuKeyVos = response["data"]["productSpuKeyVos"][0]
-    skuKeys = productSpuKeyVos["skuKeys"]
-    spuId = productSpuKeyVos["spuId"]
-    return skuKeys,spuId,response
+    items = response["data"]["openApiProductDetails"]
+    # productSpuKeyVos = response["data"]["productSpuKeyVos"][0]
+    # skuKeys = productSpuKeyVos["skuKeys"]
+    # spuId = productSpuKeyVos["spuId"]
+    # return skuKeys,spuId,response
+    type = "spu"
+    quantity = 100
+    if "type" in data:
+        type = data["type"]
+    if "quantity" in data:
+        quantity = data["quantity"]
+    if "query" in data:
+        query = data["query"]
+    variant_options_list = jsonpath(items, "$..variations")
+    product_info = ""
+    spu_id = ""
+    sku_id = ""
+    sku_id_quantity = []
+
+    for a, b in enumerate(variant_options_list):
+        if type == "spu" and b == [] and quantity != 0:
+            quantitys = items[a]["totalOrderableQuantity"]
+            unlimited_quantity = items[a]["unlimitedQuantity"]
+            if quantitys != 0 or unlimited_quantity == True:
+                product_info = items[a]
+                spu_id = items[a]["id"]
+                break
+        elif type == "sku" and b != [] and quantity != 0:
+            quantitys = items[a]["totalOrderableQuantity"]
+            unlimited_quantity = items[a]["unlimitedQuantity"]
+            if quantitys != 0 or unlimited_quantity == True:
+                product_info = items[a]
+                spu_id = items[a]["id"]
+                sku_id = jsonpath(items[a]["variations"], "$..id")
+                sku_id_quantity = jsonpath(items[a]["variations"], "$..totalOrderableQuantity")
+                break
+        elif type == "spu" and b == [] and quantity == 0:
+            quantitys = items[a]["totalOrderableQuantity"]
+            unlimited_quantity = items[a]["unlimitedQuantity"]
+            if quantitys != 0 or unlimited_quantity == True:
+                product_info = items[a]
+                spu_id = items[a]["id"]
+                break
+        elif type == "sku" and b != [] and quantity == 0:
+            quantitys = items[a]["totalOrderableQuantity"]
+            unlimited_quantity = items[a]["unlimited_quantity"]
+            if quantitys != 0 or unlimited_quantity == True:
+                product_info = items[a]
+                spu_id = items[a]["id"]
+                sku_id = jsonpath(items[a]["variations"], "$..id")
+                sku_id_quantity = jsonpath(items[a]["variations"], "$..totalOrderableQuantity")
+                break
+    return spu_id, sku_id, sku_id_quantity, product_info
 
 
 def model_one_add_product(data):
     """
-    贴文销售模式1-模式3添加商品，只添加第一个商品到贴文
+    贴文销售模式1-模式3添加商品，只添加第一个有库存商品到贴文
     :param data:
     :return:
     """
@@ -461,25 +549,27 @@ def model_one_add_product(data):
     headers = data["headers"]
     sales_id = data["sales_id"]
     url = "%s/api/posts/post/sales/%s/products"%(env,sales_id)
-    skuKeys, spuId, response = search_post_product(data)
+    spu_id, sku_id, sku_id_quantity, product_info = search_post_product(data)
+    # print("sku_id",sku_id)
     skuList = []
     body = {}
-    if skuKeys != None:
-        for index, sku in enumerate(skuKeys):
-            skuId = sku["skuId"]
-            spuId = sku["spuId"]
+    if len(sku_id) >1:
+        for index, sku in enumerate(sku_id):
+            # skuId = sku["skuId"]
+            # spuId = sku["spuId"]
             sku_data = {}
-            sku_data["skuId"] = skuId
+            sku_data["skuId"] = sku
             sku_data["missCommonKey"] = False
             sku_data["keyList"] = ["模式1关键字%d" % index]
             skuList.append(sku_data)
     # print(skuList)
-    if skuList == []:
+    if len(sku_id)<=1:
         body = {
-            "spuList": [{"spuId": spuId, "missCommonKey": "false", "customNumbers": [], "keyList": ["无规格商品关键字"]}]}
+            "spuList": [{"spuId": spu_id, "missCommonKey": "false", "customNumbers": [], "keyList": ["无规格商品关键字"]}]}
     else:
         body = {
-            "spuList": [{"spuId": spuId, "missCommonKey": "false", "customNumbers": [], "skuList": skuList}]}
+            "spuList": [{"spuId": spu_id, "missCommonKey": "false", "customNumbers": [], "skuList": skuList}]}
+    # print(body)
     response = requests.post(url, headers=headers, json=body).json()
     return response
 
@@ -493,25 +583,25 @@ def model_four_add_product(data):
     headers = data["headers"]
     sales_id = data["sales_id"]
     url = "%s/api/posts/post/sales/%s/products"%(env,sales_id)
-    skuKeys, spuId, response = search_post_product(data)
+    spu_id, sku_id, sku_id_quantity, product_info = search_post_product(data)
     skuList = []
-    if skuKeys != None:
-        for index, sku in enumerate(skuKeys):
-            skuId = sku["skuId"]
-            spuId = sku["spuId"]
+    if len(sku_id) >1:
+        for index, sku in enumerate(sku_id):
+            # skuId = sku["skuId"]
+            # spuId = sku["spuId"]
             sku_data = {}
-            sku_data["skuId"] = skuId
+            sku_data["skuId"] = sku
             sku_data["missCommonKey"] = False
             skuList.append(sku_data)
     # print(skuList)
     customNumbers = "模式4接口关键字下单"
     body = {}
-    if skuList == []:
+    if len(sku_id) <= 1:
         body = {"spuList": [
-            {"spuId": spuId, "missCommonKey": "true", "customNumbers": [customNumbers], "customNumber": customNumbers}]}
+            {"spuId": spu_id, "missCommonKey": "true", "customNumbers": [customNumbers], "customNumber": customNumbers}]}
     else:
         body = {"spuList": [
-            {"spuId": spuId, "missCommonKey": "false", "customNumbers": [customNumbers], "customNumber": customNumbers,
+            {"spuId": spu_id, "missCommonKey": "false", "customNumbers": [customNumbers], "customNumber": customNumbers,
              "skuList": skuList}]}
     response = requests.post(url, headers=headers, json=body).json()
     return response
@@ -634,6 +724,9 @@ def send_post_comment(data):
     """
     #获取关联的贴文信息-第一则贴文
     type = "post"
+    platform = "FACEBOOK"
+    if "platform" in data:
+        platform = data["platform"]
     if "type" in data:
         type = data["type"]
     response = {}
@@ -644,6 +737,9 @@ def send_post_comment(data):
     related_post_list = response["data"]["related_post_list"][0]
     page_id = related_post_list["page_id"]
     post_id = related_post_list["post_id"]
+    platform = related_post_list["platform"]
+    group_id = related_post_list["group_id"]
+    # print("请求的平台是",platform)
     stamp = int(time.time())
     num = random.randint(100000, 999999)
     env = data["env"]
@@ -652,7 +748,7 @@ def send_post_comment(data):
         user_id = data['user_id']
     name = "test post%d" % int(time.time())
     if "name" in data:
-        user_id = data['name']
+        name = data['name']
     comment_id = "%s_%d%d" % (page_id, stamp, num)
     if "comment_id" in data:
         comment_id = data['comment_id']
@@ -660,17 +756,35 @@ def send_post_comment(data):
     if "keyword" in data:
         keyword = data['keyword']
     key = data["key"]
-    body = {"object": "page", "entry": [{"id": page_id, "time": stamp, "changes": [{"field": "feed", "value": {
+    body = {}
+    if platform=="FACEBOOK":
+        body = {"object": "page", "entry": [{"id": page_id, "time": stamp, "changes": [{"field": "feed", "value": {
         "from": {"id": user_id, "name": name},
         "post": {"status_type": "added_video", "is_published": True, "updated_time": "2022-11-18T09:57:26+0000",
                  "permalink_url": "https://www.facebook.com/permalink.php?story_fbid=pfbid02jLK3e6YdFSXp2DmD7j7vtStLXoBzTi8rxKrp6jFhVMUTTEgz6qvZA8soR9Uwydd8l&id=107977035056574",
                  "promotion_status": "inactive", "id": post_id}, "message": keyword, "item": "comment",
         "verb": "add", "post_id": post_id, "comment_id": comment_id,
         "created_time": stamp, "parent_id": post_id}}]}]}
+    elif platform=="INSTAGRAM":
+        body = {"entry": [{"id": page_id, "time": stamp, "changes": [{"value": {"from": {"id": user_id,
+         "username": name}, "media": {"id": post_id, "media_product_type": "FEED"},
+         "id": comment_id, "text": keyword}, "field": "comments"}]}], "object": "instagram"}
+    elif platform.upper() == "FB_GROUP":
+        t_time = stamp * 1000
+        post_id = post_id.split("_")[-1]
+        comment_id = "%d%d" % (stamp, num)
+        body = {"object": "page", "entry": [
+            {"id": page_id, "time": t_time, "messaging": [{"recipient": {"id": page_id}, "message": keyword,
+                                                           "from": {"id": user_id, "name": name}, "group_id": group_id,
+                                                           "post_id": post_id, "comment_id": comment_id,
+                                                           "created_time": stamp, "item": "comment",
+                                                           "verb": "add", "parent_id": post_id,
+                                                           "field": "group_feed"}]}]}
+
     url = "%s/facebook/webhook"%env
     sign_text = hmac.new(key.encode("utf-8"), json.dumps(body).encode("utf-8"), sha1)
     signData = sign_text.hexdigest()
-    print(signData)
+    print("body",json.dumps(body))
     header = {"Content-Type": "application/json", "x-hub-signature": "sha1=%s" % signData}
     response = requests.post(url, headers=header, data=json.dumps(body))
     return user_id,name,comment_id
@@ -687,7 +801,17 @@ def get_payment(data):
     headers = data["headers"]
     url ="%s/openApi/proxy/v1/payments?page=1&per_page=10&include_fields[]=config_data.tappay"%env
     response = requests.get(url, headers=headers).json()
-    payment_id = response["data"]["items"][0]["id"]
+    payment_types = [item["type"] for item in response["data"]["items"]]
+    payment_id = ""
+    for payment in payment_types:
+        # print(delivery)
+        if payment == "bank_transfer":
+            index = payment_types.index(payment)
+            payment_info = response["data"]["items"][index]
+            payment_id = payment_info["id"]
+            break
+    if payment_id == "":
+        payment_id = response["data"]["items"][0]["id"]
     return payment_id,response
 
 def get_delivery(data):
@@ -699,9 +823,20 @@ def get_delivery(data):
     # print("物流data",data)
     env = data["env"]
     headers = data["headers"]
-    url = "%s/openApi/proxy/v1/delivery_options?page=1&per_page=10"%env
+    url = "%s/openApi/proxy/v1/delivery_options?page=1&per_page=998"%env
     response = requests.get(url, headers=headers).json()
-    delivery_id = response["data"]["items"][0]["id"]
+    # print(response)
+    delivery_types = [item["region_type"] for item in response["data"]["items"]]
+    delivery_id = ""
+    for delivery in delivery_types:
+        # print(delivery)
+        if delivery == "custom":
+            index = delivery_types.index(delivery)
+            delivery_info = response["data"]["items"][index]
+            delivery_id = delivery_info["id"]
+            break
+    if delivery_id=="":
+        delivery_id = response["data"]["items"][0]["id"]
     return delivery_id,response
 
 def get_comment_user(data):
@@ -712,8 +847,11 @@ def get_comment_user(data):
     env = data["env"]
     headers = data["headers"]
     sales_id = data["sales_id"]
-    url = "%s/api/posts/post/comments"%env
     params = {"pageNo":1,"pageSize":10,"salesId":sales_id}
+    if "query" in data:
+        query = data["query"]
+        params["query"] = query
+    url = "%s/api/posts/post/comments"%env
     response = requests.get(url, headers=headers,params=params).json()
     post_user_id = jsonpath(response, "$..id")[0]
     return post_user_id,response
@@ -764,26 +902,35 @@ def merge_customer(data):
     user_id = data["user_id"]
     page_id = data["page_id"]
     platform = data["platform"]
+    customer_id  = jsonpath(response,"$..customer_id")[0]
 
-    response = search_customer(data)
-    items = response["data"]["items"]
-    # 创建会员
-    customer_id = ""
-    url = "%s/uc/customers/merge" % env
-    body = {"email": "", "mobile_phone": phone, "mobile_phone_country_calling_code": "86",
-            "name": name, "page_scoped_id": user_id, "locale_code": None, "country_code": "cn",
-            "id": None, "party_channel_id": page_id, "platform": platform, "is_member": True}
-    if items != []:
-        id = jsonpath(response, "$..id")[0]
-        customer_id = id
+    if customer_id==None:
+        response = search_customer(data)
+        items = response["data"]["items"]
+        # 创建会员
+        url = "%s/uc/customers/merge" % env
         body = {"email": "", "mobile_phone": phone, "mobile_phone_country_calling_code": "86",
                 "name": name, "page_scoped_id": user_id, "locale_code": None, "country_code": "cn",
-                "id": id, "party_channel_id": page_id, "platform": platform, "is_member": True}
-    response = requests.put(url, headers=headers, json=body)
-
-    # print("创建会员请求体",body)
-    if response.raise_for_status():
-        customer_id = response.json()["data"]["id"]
+                "id": None, "party_channel_id": page_id, "platform": platform, "is_member": True}
+        if items != []:
+            id = jsonpath(response, "$..id")[0]
+            customer_id = id
+            body = {"email": "", "mobile_phone": phone, "mobile_phone_country_calling_code": "86",
+                    "name": name, "page_scoped_id": user_id, "locale_code": None, "country_code": "cn",
+                    "id": id, "party_channel_id": page_id, "platform": platform, "is_member": True}
+        response = requests.put(url, headers=headers, json=body)
+        print("合并会员返回",response.json())
+        # print("创建会员请求体",body)
+        if response.raise_for_status():
+            customer_id = response.json()["data"]["id"]
+        elif response.json()["code"]=="UC0409":
+            email = "%d@qq.com"%int(time.time())
+            body = {"email": email, "mobile_phone": "", "mobile_phone_country_calling_code": "86",
+                    "name": name, "page_scoped_id": user_id, "locale_code": None, "country_code": "cn",
+                    "id": "", "party_channel_id": page_id, "platform": platform, "is_member": False}
+            response = requests.put(url, headers=headers, json=body)
+        else:
+            customer_id = response.json()["data"]["id"]
     return response,customer_id
 
 
@@ -814,8 +961,8 @@ def manual_order(data):
     # 先查询号码或邮箱是否被占有
     #创建会员
     response,customer_id = merge_customer(data)
-    print("会员ID",customer_id)
-    print("创建会员返回，",response.text)
+    # print("会员ID",customer_id)
+    # print("创建会员返回，",response.text)
     #给会员新增物流地址
     url = "%s/uc/customers/%s" % (env,customer_id)
     postcode = "76653"
@@ -867,11 +1014,11 @@ def manual_order(data):
             "source_data": {"type": "fb", "source_id": page_id}, "customer_phone_country_code": "86",
             "postcode": postcode}
     res = requests.post(url,headers=headers,json=body)
-    print("创建订单返回",res.text)
+    # print("创建订单返回",res.text)
     #获取订单ID
     orderNumber = ""
-    if res.raise_for_status():
-        orderNumber = jsonpath(res,"$..orderNumber")[0]
+    if res.status_code==200:
+        orderNumber = jsonpath(res.json(),"$..orderNumber")[0]
     return orderNumber,customer_id,res
 
 def get_user_conversation_id(data):
@@ -889,8 +1036,9 @@ def get_user_conversation_id(data):
         platform = data["platform"].lower()
     url = "%s/mc/conversation/id?type=%s&user_id=%s&party_channel_id=%s" % (env, platform, user_id, page_id)
     # param = {"type":"facebook","user_id":vars["user_id"],"party_channel_id":vars["platform_channel_id"]}
+    print(url)
     response = requests.get(url, headers=headers).json()
-    print(response)
+
     conversation_id = jsonpath(response, "$.data.id")[0]
     return conversation_id,response
 
@@ -932,9 +1080,12 @@ def modify_order_status(data):
         customer_id = data["customer_id"]
     else:
         __,customer_id,__ = manual_order(data)
-    url = "%s/v1/orders/search?page=1&per_page=5&customer_id=%s" % (oa_env,customer_id)
-    res = requests.get(url, headers=oa_headers).json()
-    order_id = jsonpath(res, "$..id")[0]
+    if "order_id" in data:
+        order_id = data["order_id"]
+    else:
+        url = "%s/v1/orders/search?page=1&per_page=5&customer_id=%s" % (oa_env,customer_id)
+        res = requests.get(url, headers=oa_headers).json()
+        order_id = jsonpath(res, "$..id")[0]
     # print("订单ID", vars["order_id"])
     # 修改订单状态为-已确认
     url = "%s/v1/orders/%s/status" % (oa_env,order_id)
@@ -943,6 +1094,7 @@ def modify_order_status(data):
         "mail_notify": False
     }
     res = requests.patch(url, headers=oa_headers, json=body).json()
+    return res
 
 def modify_order_payment_status(data):
     """
@@ -964,9 +1116,12 @@ def modify_order_payment_status(data):
         customer_id = data["customer_id"]
     else:
         __,customer_id,__ = manual_order(data)
-    url = "%s/v1/orders/search?page=1&per_page=5&customer_id=%s" % (oa_env,customer_id)
-    res = requests.get(url, headers=oa_headers).json()
-    order_id = jsonpath(res, "$..id")[0]
+    if "order_id" in data:
+        order_id = data["order_id"]
+    else:
+        url = "%s/v1/orders/search?page=1&per_page=5&customer_id=%s" % (oa_env, customer_id)
+        res = requests.get(url, headers=oa_headers).json()
+        order_id = jsonpath(res, "$..id")[0]
     # print("订单ID", vars["order_id"])
     # 修改订单状态为-已确认
     url = "%s/v1/orders/%s/order_payment_status" % (oa_env,order_id)
@@ -975,6 +1130,7 @@ def modify_order_payment_status(data):
         "mail_notify": False
     }
     res = requests.patch(url, headers=oa_headers, json=body).json()
+    return res
 
 def modify_order_delivery_status(data):
     """
@@ -986,7 +1142,7 @@ def modify_order_delivery_status(data):
     arrived：已到达
     collected：已取货
     returned：已退货
-    returning：退款中
+    returning：退回中
     :return:
     """
     oa_env = data["oa_env"]
@@ -998,9 +1154,12 @@ def modify_order_delivery_status(data):
         customer_id = data["customer_id"]
     else:
         __,customer_id,__ = manual_order(data)
-    url = "%s/v1/orders/search?page=1&per_page=5&customer_id=%s" % (oa_env,customer_id)
-    res = requests.get(url, headers=oa_headers).json()
-    order_id = jsonpath(res, "$..id")[0]
+    if "order_id" in data:
+        order_id = data["order_id"]
+    else:
+        url = "%s/v1/orders/search?page=1&per_page=5&customer_id=%s" % (oa_env, customer_id)
+        res = requests.get(url, headers=oa_headers).json()
+        order_id = jsonpath(res, "$..id")[0]
     # print("订单ID", vars["order_id"])
     # 修改订单状态为-已确认
     url = "%s/v1/orders/%s/order_delivery_status" % (oa_env,order_id)
@@ -1009,6 +1168,7 @@ def modify_order_delivery_status(data):
         "mail_notify": False
     }
     res = requests.patch(url, headers=oa_headers, json=body).json()
+    return res
 
 def delete_post(data):
     env = data["env"]
@@ -1027,6 +1187,10 @@ def modelone_create_single_product(data):
     env = data["env"]
     headers = data["headers"]
     sales_id = data["sales_id"]
+    quantity = 1000
+    price = 3
+    if "quantity" in data:
+        quantity = data["quantity"]
     url = "%s/api/posts/post/sales/%s/product/create" % (env, sales_id)
     product_name = "post接口新增商品多规格商品名称%d" % int(time.time())
     if "product_name" in data:
@@ -1034,12 +1198,42 @@ def modelone_create_single_product(data):
     keyword = "post接口新增商品多规格商品关键字%d" % int(time.time())
     if "keyword" in data:
         keyword = data["keyword"]
-    body = {"customKey":keyword,"quantity":5,"unlimitedQuantity":False,"productName":product_name,
+    if "price" in data:
+        price = data["price"]
+    body = {"customKey":keyword,"quantity":quantity,"unlimitedQuantity":False,"productName":product_name,
+            "imageUrl":"https://s3-ap-southeast-1.amazonaws.com/static.shoplineapp.com/sc-admin/product-default.png","price":price}
+    response = requests.post(url,headers=headers,json=body).json()
+    # print(body)
+    print(response)
+    spu_id = response["data"]
+    return spu_id
+
+def modelfour_create_single_product(data):
+    """
+    贴文新增无规格商品
+    :param data:
+    :return: 返回新增的商品的spu_id
+    """
+    env = data["env"]
+    headers = data["headers"]
+    sales_id = data["sales_id"]
+    quantity = 1000
+    if "quantity" in data:
+        quantity = data["quantity"]
+    url = "%s/api/posts/post/sales/%s/product/create" % (env, sales_id)
+    product_name = "post接口新增商品多规格商品名称%d" % int(time.time())
+    if "product_name" in data:
+        product_name = data["product_name"]
+    keyword = "post接口新增商品多规格商品关键字%d" % int(time.time())
+    if "keyword" in data:
+        keyword = data["keyword"]
+    body = {"customNumber":keyword,"quantity":quantity,"unlimitedQuantity":False,"productName":product_name,
             "imageUrl":"https://s3-ap-southeast-1.amazonaws.com/static.shoplineapp.com/sc-admin/product-default.png","price":3}
     response = requests.post(url,headers=headers,json=body).json()
     spu_id = response["data"]
     return spu_id
 
+
 def modelone_create_mutil_product(data):
     """
     贴文新增多规格商品，
@@ -1059,30 +1253,67 @@ def modelone_create_mutil_product(data):
         keyword = data["keyword"]
     variance = {"color":["红","黄"],"size":["X","M"]}
     if "variance" in data:
-     variance = data["variance"]
+        variance = data["variance"]
+    price = 10
+    if "price" in data:
+        price = data["price"]
+    quantity = 99
+    if "quantity" in data:
+        quantity = data["quantity"]
     customVariantTypes = []
     variantOptions = []
     variations = []
     variance_type = variance.keys()
+    # print(variance_type)
     custom_keys = []
     for index,value in enumerate(variance_type):
+        # print(value)
         customVariantType = {}
-        customVariantType["type"] = "custom_%d"%(index+1)
+        type = "custom_%d"%(index+1)
+        customVariantType["type"] = type
         customVariantType["name"] = value
         customVariantTypes.append(customVariantType)
         variance_names = variance[value]
+        # print(variance_names)
         custom_key = []
         for index,value in enumerate(variance_names):
             variantOption = {}
-            variantOption["type"] = "custom_%d"%(index+1)
-            customVariantType["name"] = value
-            customVariantType["key"] = "custom_%d_%s_4218"%(index+1,value)
-            custom_key.append(customVariantType["key"])
+            variantOption["type"] = type
+            variantOption["name"] = value
+            variantOption["key"] = "%s_%s_4218"%(type,value)
+            custom_key.append(variantOption["key"])
             variantOptions.append(variantOption)
         custom_keys.append(custom_key)
+    # print(customVariantTypes)
+    # print(variantOptions)
+    # print(custom_keys)
+    # 生成所有组合
+    combinations = []
+    for i in range(len(custom_keys)):
+        for j in range(i + 1, len(custom_keys)):
+            # 使用 itertools.product 生成每对子数组的组合
+            combinations.extend(itertools.product(custom_keys[i], custom_keys[j]))
+    for i in range(len(combinations)):
+        variantion = {}
+        variantion["price"] = price
+        variantion["quantity"] = quantity
+        variantion["keyList"] = [keyword + "%d" % i]
+        variantion["variantOptionKeys"] = list(combinations[i])
+        variations.append(variantion)
+    # print(variations)
 
-    # body = {"unlimitedQuantity":False,"productName":product_name,"imageUrl":"https://s3-ap-southeast-1.amazonaws.com/static.shoplineapp.com/sc-admin/product-default.png",
-    #         "customVariantTypes":,"price":0}
+    body = {
+        "unlimitedQuantity": False,
+        "productName": product_name,
+        "imageUrl": "https://s3-ap-southeast-1.amazonaws.com/static.shoplineapp.com/sc-admin/product-default.png",
+        "customVariantTypes":customVariantTypes,
+        "variantOptions": variantOptions,
+        "variations": variations,
+        "price": 0
+    }
+    response = requests.post(url, headers=headers, json=body).json()
+    spu_id = response["data"]
+    return spu_id
 
 def get_mc_post(data):
     """
@@ -1092,17 +1323,18 @@ def get_mc_post(data):
     """
     env = data["env"]
     headers = data["headers"]
-    page_id = ""
+    # page_id = ""
     if "page_id" in data:
         page_id = data["page_id"]
     else:
         response = get_post_info(data)
         page_id = jsonpath(response,"$..page_id")[0]
-    url = "%s/mc/postcomment/post"%env
+    url = "%s/mc/postcomment/posts"%env
+    # print(url)
     params = {"platform_channel_id":page_id,"staff_id":"all","page_num":1,"page_size":100}
     response = requests.get(url, headers=headers,params=params).json()
     id = jsonpath(response,"$..id")
-    post_id = jsonpath(response,"$..post_id")
+    post_id = jsonpath(response,"$..fb_post_id")
     return id,post_id,response
 
 def get_post_comment(data):
@@ -1114,12 +1346,15 @@ def get_post_comment(data):
     env = data["env"]
     headers = data["headers"]
     id_list, post_id_list, __ = get_mc_post(data)
+    print("id_list",id_list)
+    print("post_id_list", post_id_list)
     post_id = ""
     if "post_id" in data:
         post_id = data["post_id"]
     else:
         response = get_post_info(data)
-        post_id = jsonpath(response, "$..post_id")[0]
+        post_id = jsonpath(response, "$..post_id")[1]
+    print("查询的贴文post_id",post_id)
     mc_post_id = 1
     for index,value in enumerate(post_id_list):
         if value==post_id:
@@ -1145,7 +1380,7 @@ def modify_message(data):
     headers = data["headers"]
     sales_id = data["sales_id"]
 
-    url = "api/posts/post/sales/%s/keyword_message"%sales_id
+    url = "%s/api/posts/post/sales/%s/keyword_message"%(env,sales_id)
     need_send_message = True
     if "need_send_message" in data:
         need_send_message = data["need_send_message"]
@@ -1298,11 +1533,162 @@ def end_post(data):
     response = requests.put(url,headers=headers).json()
     return response
 
+def get_oa_payment(data):
+    env = data["env"]
+    headers = data["headers"]
+    type_value = data["type"]
+    name = ""
+    if "name" in data:
+        name = data["name"]
+    url = "%s/openApi/proxy/v1/payments?page=1&per_page=999&include_fields[]=config_data.tappay"%env
+    response = requests.get(url,headers=headers).json()
+    type_list = [item["type"] for item in response["data"]["items"]]
+    payment_ids = []
+    for i in type_list:
+        if i==type_value:
+            index = type_list.index(i)
+            payment_id = response["data"]["items"][index]["id"]
+            payment_ids.append(payment_id)
+    return payment_ids,response
+
+def get_oa_delivery(data):
+    env = data["env"]
+    headers = data["headers"]
+    type_value = data["type"]
+    name = ""
+    if "name" in data:
+        name = data["name"]
+    url = "%s/openApi/proxy/v1/delivery_options?page=1&per_page=999"%env
+    response = requests.get(url,headers=headers).json()
+    type_list = [item["type"] for item in response["data"]["items"]]
+    delivery_ids = []
+    for i in type_list:
+        if i==type_value:
+            index = type_list.index(i)
+            delivery_id = response["data"]["items"][index]["id"]
+            delivery_ids.append(delivery_id)
+    return delivery_ids,response
+
+def set_payment(data):
+    env = data["env"]
+    headers = data["headers"]
+    customer_id = data["customer_id"]
+    owner_type = data["owner_type"]
+    url = "%s/openApi/proxy/v1/internal/mc/api/carts/%s?owner_type=%s&cart_uid=%s&created_by=sc_manual_order&skip_reapply_promotion=false"%(
+        env,customer_id,owner_type,customer_id
+    )
+    payment_id = ""
+    if "payment_id" in data:
+        payment_id = data["payment_id"]
+    else:
+        payment_ids,__ = get_oa_payment(data)
+        payment_id = payment_ids[0]
+    body = {
+
+      "owner_id": customer_id,
+      "payment_id": payment_id
+    }
+    response = requests.put(url, headers=headers, json = body).json()
+    return response
+
+
+def set_delivery(data):
+    env = data["env"]
+    headers = data["headers"]
+    customer_id = data["customer_id"]
+    owner_type = data["owner_type"]
+    url = "%s/openApi/proxy/v1/internal/mc/api/carts/%s?owner_type=%s&cart_uid=%s&created_by=sc_manual_order&skip_reapply_promotion=false" % (
+        env, customer_id, owner_type, customer_id
+    )
+    country = "TW"
+    if "country" in data:
+        country = data["country"]
+    delivery_id = ""
+    if "delivery_id" in data:
+        delivery_id = data["delivery_id"]
+    else:
+        delivery_ids, __ = get_oa_delivery(data)
+        delivery_id = delivery_ids[0]
+    body = {
+      "delivery_option_id": delivery_id,
+      "country": country,
+      "owner_id": customer_id,
+      "payment_id": ""
+    }
+    response = requests.put(url, headers=headers, json=body).json()
+    return response
+
+def get_mc_order_link(url):
+    response = requests.get(url)
+    print(response.headers)
+    location = response.headers.get("Location")
+    # print(location)
+    key = location.split("/")[-1].split("?")[0]
+    return key
+
+def edit_message(data):
+    env = data["env"]
+    headers = data["headers"]
+    sales_id = data["sales_id"]
+    url = "%s/api/posts/post/sales/%s/keyword_message" % (env,sales_id)
+    has_interaction_message = "您好，以下商品加单成功！购物车商品总金额: 请按以下按钮结账%d" % int(time.time())
+    no_interaction_message_first = "您好，以下商品加单成功 !购物车商品总金额: 请按以下按钮继续」%d" % int(time.time())
+    second_message = "您好，以下商品加单成功！{products} 购物车商品总金额: {total}请前往购物网站！%d" % int(time.time())
+    first_message_button = "继续"
+    second_message_button = "立即结帐 ️"
+    need_send_message = True
+    message_button = "立即结帐️"
+    has_link = True
+    #留言回复comment_reply
+    comment_reply = True
+    comment_reply_content = "testcopypost您好，谢谢你在贴文下留言订购以下商%d." % int(time.time())
+    #无库存信息
+    all_out_of_stock =True
+    all_out_of_stock_content = "您好，{customerName}，以下商品库存不足，请选购其他商品，谢谢！{products}%d" % int(time.time())
+    if "has_interaction_message" in data:
+        has_interaction_message = data["has_interaction_message"]
+    if "no_interaction_message_first" in data:
+        has_interaction_message = data["no_interaction_message_first"]
+    if "first_message_button" in data:
+        first_message_button = data["first_message_button"]
+    if "second_message" in data:
+        second_message = data["second_message"]
+    if "second_message_button" in data:
+        second_message_button = data["second_message_button"]
+    if "need_send_message" in data:
+        need_send_message = data["need_send_message"]
+    if "message_button" in data:
+        message_button = data["message_button"]
+    if "has_link" in data:
+        has_link = data["has_link"]
+    if "comment_reply" in data:
+        comment_reply = data["comment_reply"]
+    if "comment_reply_content" in data:
+        comment_reply_content = data["comment_reply_content"]
+    if "all_out_of_stock" in data:
+        all_out_of_stock = data["all_out_of_stock"]
+    if "all_out_of_stock_content" in data:
+        all_out_of_stock_content = data["all_out_of_stock_content"]
+
+    message = {"has_interaction_message":has_interaction_message,"no_interaction_message_first":no_interaction_message_first,
+               "first_message_button":first_message_button,"second_message_button":second_message_button,"second_message":second_message,
+              "comment_reply_content":comment_reply_content,"all_out_of_stock_content" :all_out_of_stock_content
+
+    }
+    body = {"message_config_req": {"need_send_message": need_send_message,
+                                   "no_interaction_message": {"first_message": no_interaction_message_first,
+                                                              "first_message_button": first_message_button,
+                                                              "second_message":second_message ,
+                                                              "second_message_button": second_message_button},
+                                   "has_interaction_message": {"first_message": has_interaction_message,
+                                                               "message_button": message_button}, "has_link": has_link},
+            "comment_reply_req": {"need_reply": comment_reply, "content": comment_reply_content},
+            "all_out_of_stock_req": {"need_reply": all_out_of_stock, "content": all_out_of_stock_content}}
+    response = requests.post(url, headers=headers, json = body).json()
+    return message,response
+
 
 
 
 if __name__=="__main__":
-    pass
-
-
-
+   pass
\ No newline at end of file
